@@ -49,6 +49,11 @@ For example:
     Ws: {windSpeed}             ->  Ws: 12.3452343
     Ws: {windSpeed:%.3f}        ->  Ws: 12.345
 
+Ordinals can be specified for wind direction:
+
+    Wd: {windDir:%03.0f}        ->  Wd: 090
+    Wd: {windDir:ORD}           ->  Wd: E
+
 The dateTime field is handled slightly differently.  For example:
 
     ts: {dateTime}              ->  ts: 1413994070
@@ -79,7 +84,7 @@ from weeutil.weeutil import to_bool, accumulateLeaves
 
 from twython import Twython, TwythonError, TwythonAuthError, TwythonRateLimitError
 
-VERSION = "0.10"
+VERSION = "0.11"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -101,10 +106,20 @@ def _format(label, fmt, datum):
     s = fmt % datum if datum is not None else "None"
     return "%s: %s" % (label, s)
 
+def _dir_to_ord(x, ordinals):
+    try:
+        return ordinals[int(round(x / 22.5))]
+    except (ValueError, IndexError):
+        pass
+    return ordinals[17]
+
+
 class Twitter(weewx.restx.StdRESTbase):
 
     _DEFAULT_FORMAT = '{station:%.8s}: Ws: {windSpeed:%.1f}; Wd: {windDir:%03.0f}; Wg: {windGust:%.1f}; oT: {outTemp:%.1f}; oH: {outHumidity:%.2f}; P: {barometer:%.3f}; R: {rain:%.3f}'
     _DEFAULT_FORMAT_NONE = '-'
+    _DEFAULT_ORDINALS = ['N', 'NNE', 'NE', 'ENE', 'E', 'ESE', 'SE', 'SSE', 'S',
+                         'SSW', 'SW', 'WSW', 'W', 'WNW', 'NW', 'NNW', 'N', '-']
 
     def __init__(self, engine, config_dict):
         """This service recognizes standard restful options plus the following:
@@ -165,6 +180,7 @@ class Twitter(weewx.restx.StdRESTbase):
         site_dict.setdefault('format_None', self._DEFAULT_FORMAT_NONE)
         site_dict.setdefault('format_utc', False)
         site_dict['format_utc'] = to_bool(site_dict.get('format_utc'))
+        site_dict.setdefault('ordinals', self._DEFAULT_ORDINALS)
 
         # we can bind to archive or loop events, default to archive
         self.binding = site_dict.get('binding', 'archive')
@@ -188,7 +204,7 @@ class Twitter(weewx.restx.StdRESTbase):
 class TwitterThread(weewx.restx.RESTThread):
     def __init__(self, queue, 
                  app_key, app_key_secret, oauth_token, oauth_token_secret,
-                 station, format, format_None, format_utc=True,
+                 station, format, format_None, ordinals, format_utc=True,
                  unit_system=None, skip_upload=False,
                  log_success=True, log_failure=True,
                  post_interval=None, max_backlog=sys.maxint, stale=None,
@@ -211,6 +227,7 @@ class TwitterThread(weewx.restx.RESTThread):
         self.station = station
         self.format = format
         self.format_None = format_None
+        self.ordinals = ordinals
         self.format_utc = format_utc
         self.unit_system = unit_system
         self.skip_upload = to_bool(skip_upload)
@@ -239,6 +256,8 @@ class TwitterThread(weewx.restx.RESTThread):
                     newstr = time.strftime(fmt, ts)
                 elif record[obs] is None:
                     newstr = self.format_None
+                elif obs == 'windDir' and fmt.lower() == 'ord':
+                    newstr = dir_to_ord(record[obs], self.ordinals)
                 else:
                     newstr = fmt % record[obs]
                 msg = msg.replace(oldstr, newstr)
